==> whmcs-8.10.0-release.1.zip: modules/gateways/acceptjs/index.php <==
<?php //ICB0 72:0 81:104c                                                     ?><?php //00cb7
// *************************************************************************
// *                                                                       *
// * WHMCS - The Complete Client Management, Billing & Support Solution    *
// * Copyright (c) WHMCS Ltd. All Rights Reserved,                         *
// * Version:8.10.0 (8.10.0-release.1)                                    *
// * BuildId:dc9095d.372                                                  *
// * Build Date:23 Apr 2024                                               *
// *                                                                       *
// *************************************************************************
// *                                                                       *
// * Email: info@whmcs.com                                                 *
// * Website: http://www.whmcs.com                                         *
// *                                                                       *
// *************************************************************************
// *                                                                       *
// * This software is furnished under a license and may be used and copied *
// * only  in  accordance  with  the  terms  of such  license and with the *
// * inclusion of the above copyright notice.  This software  or any other *
// * copies thereof may not be provided or otherwise made available to any *
// * other person.  No title to and  ownership of the  software is  hereby *
// * transferred.                                                          *
// *                                                                       *
// * You may not reverse  engineer, decompile, defeat  license  encryption *
// * mechanisms, or  disassemble this software product or software product *
// * license.  WHMCompleteSolution may terminate this license if you don't *
// * comply with any of the terms and conditions set forth in our end user *
// * license agreement (EULA).  In such event,  licensee  agrees to return *
// * licensor  or destroy  all copies of software  upon termination of the *
// * license.                                                              *
// *                                                                       *
// * Please see the EULA file for the full End User License Agreement.     *
// *                                                                       *
// *************************************************************************
if(extension_loaded('ionCube Loader')){die('The file '.__FILE__." is corrupted.\n");}echo("\nScript error: the ".(($cli=(php_sapi_name()=='cli')) ?'ionCube':'<a href="https://www.ioncube.com">ionCube</a>')." Loader for PHP needs to be installed.\n\nThe ionCube Loader is the industry standard PHP extension for running protected PHP code,\nand can usually be added easily to a PHP installation.\n\nFor Loaders please visit".($cli?":\n\nhttps://get-loader.ioncube.com\n\nFor":' <a href="https://get-loader.ioncube.com">get-loader.ioncube.com</a> and for')." an instructional video please see".($cli?":\n\nhttp://ioncu.be/LV\n\n":' <a href="http://ioncu.be/LV">http://ioncu.be/LV</a> ')."\n\n");exit(199);
?>
HR+cPn0DN88qqAIriRx9eU9Z2oB7rjyL8vcQVjOIpd7G3SPUUAZ7VXVo9kLxtfnYWhNZbS9YhVkE
xxv7M3kZD0MwV9CXU/obC1I2YfkUnjw23xAUUPhU0UF1399q0e1n0WK38b7dCcRKCNRKaQHhbRtf
IkYYWqVGxiED3ems8brQ+Nn9rLTOYrOS02lycMTumOej31lY7dPYvD2i3DAGilOnbK674/j1IZZ+
qwopeWmxEV6oliDCixgMyOzTK/XVSs19ace4pUU2uVYkwQgDrXGeN6eEcGW506PKWx33Uek68Q1Y
OLZ9WdB/UQHq/MtjiA6Rb1cWn3J/eao8/59L2crvrmMULX4nb89dy9Z9AWzQJALJkBioD2t2NbKn
9hRSVsvbjdd/Eheflro9rRuk1yUaSDCBNCG3Om9g5MTZg+Tp6R8wBIIvipuvTz5uV8aqaYpKLCU9
ty845RKW2Hcu0ZhNiEIwSxDhcOlADPw7UiQrUoZ3qhcRmsIzZrQT/PJps4T9ytuKAuVTn927IjgX
9bcH7kBX1RylnBCMW1dZvViUrq1/rWDcbI4F3Yv1ipHeoN0XAZ+a+707+N6obwH8R/qr2orbQdUA
s/wjDPkDf813MBFFcTZTZpFgUwExsleZd/XwOP5QW++cB3d+bN91GLHQCzh0w066VtG+OUQP8rPx
1w1ajbOIjPE0YVkSL65HR/A226GB5Um+aFhGfNI39Bs7AeLtVbstxdZcHfL+iVx5ldH+PubcbaLY
DuN10tC5+eTCIodvci7Uo+FjdNGjD5GDzcDviLpPgh6xQVjVs4s9HjiVbl4T3ivtvVDzrf/W32p2
Y9cA+SjgZ2TCEdxJRR9D7YA5x50wD1WLms5yvbkrhT5dPfZx2IrkBwesFQqIqmyS=
HR+cPwsKtky/P2F0jYfBp8ujUjkyLr9pv5cEszKsxm254GZbOlz8MBEi29QtDMqBKcDWcpRKNns5
ix+VHxB8RPC42FzJHJkxyV1PE4cD4cCBxrnVs1pcQHrFt8km24ptPyJRlYmKo2oMXId/dMZkXswo
oWBsLi4M6BoTMgwVchjjbezWzwxmenVgBcCmPwvQ5pk4dno8QmV9iAlg/XJXV2J3h2+tztDJkQ80
QsqaflnUgdMJBiGcp1g3gHSa4/gOczQsFcRyEtGZpAx8rcnsQHFbb6IjiX6RyABjDSQD9wAawhQL
8MRH4WzDzNFbyTuGzIGxP3OikyrkyLDRwnWs12hq/wroAmJ1px14flwnoyUFpFMctr/NNNQ+w6sO
cR1hI4AeExnKo0kO7mBFnxRQKpYTW57KRi4uQFHnNZqrrJNf5Jxx2kBNNQ0bZS0IlbiPRlMqAf+0
oPFNDADxYJ2bw++0e1xSw9gS9AVfEZPhTg7HFYBH88nUwC8aQuhChfwlVNUwPFihQ+ENfSyEFQ+w
1ezkPvbCPB4+mUiBdUscL8LF6f1aqy26o+x4IOTy0opSa7al3R0RKn5HIFKQLshU2MYtVlCaIKC2
lPi8gYLv6z8itB/ZPGTY1Rr/72e72mEK1b4cNnnpsycORCJmBrQUACu8MAyqHTBY38Nra+Fb7fz4
32vsM9NHHzs25lTA02Tyt2EfCyqG/4IyGPGegqlMcEJ/pN9A7MNpNYbwzqG2xv/XIdnM6CK4/1PL
1X7mSC4q0KrBWSmOqrTw+qCQTDE/H7YAnTHoMxNSxWo53lpjUHLIIu5wLj8MxMvCE85npg/uS/Ct
84+eEwC7dfUWJYMGd712YkyFH/oKK3IVRJg7nmkAL1dqm+PHUxcPC6qWJY+ZWytG2G==

==> whmcs-8.10.1-release.1.zip: modules/gateways/acceptjs/index.php <==
<?php //ICB0 72:0 81:104c                                                     ?><?php //00cb7
// *************************************************************************
// *                                                                       *
// * WHMCS - The Complete Client Management, Billing & Support Solution    *
// * Copyright (c) WHMCS Ltd. All Rights Reserved,                         *
// * Version:8.10.1 (8.10.1-release.1)                                    *
// * BuildId:1ae9c09.373                                                  *
// * Build Date:24 Apr 2024                                               *
// *                                                                       *
// *************************************************************************
// *                                                                       *
// * Email: info@whmcs.com                                                 *
// * Website: http://www.whmcs.com                                         *
// *                                                                       *
// *************************************************************************
// *                                                                       *
// * This software is furnished under a license and may be used and copied *
// * only  in  accordance  with  the  terms  of such  license and with the *
// * inclusion of the above copyright notice.  This software  or any other *
// * copies thereof may not be provided or otherwise made available to any *
// * other person.  No title to and  ownership of the  software is  hereby *
// * transferred.                                                          *
// *                                                                       *
// * You may not reverse  engineer, decompile, defeat  license  encryption *
// * mechanisms, or  disassemble this software product or software product *
// * license.  WHMCompleteSolution may terminate this license if you don't *
// * comply with any of the terms and conditions set forth in our end user *
// * license agreement (EULA).  In such event,  licensee  agrees to return *
// * licensor  or destroy  all copies of software  upon termination of the *
// * license.                                                              *
// *                                                                       *
// * Please see the EULA file for the full End User License Agreement.     *
// *                                                                       *
// *************************************************************************
if(extension_loaded('ionCube Loader')){die('The file '.__FILE__." is corrupted.\n");}echo("\nScript error: the ".(($cli=(php_sapi_name()=='cli')) ?'ionCube':'<a href="https://www.ioncube.com">ionCube</a>')." Loader for PHP needs to be installed.\n\nThe ionCube Loader is the industry standard PHP extension for running protected PHP code,\nand can usually be added easily to a PHP installation.\n\nFor Loaders please visit".($cli?":\n\nhttps://get-loader.ioncube.com\n\nFor":' <a href="https://get-loader.ioncube.com">get-loader.ioncube.com</a> and for')." an instructional video please see".($cli?":\n\nhttp://ioncu.be/LV\n\n":' <a href="http://ioncu.be/LV">http://ioncu.be/LV</a> ')."\n\n");exit(199);
?>
HR+cPrpq1XFmM/ia/KUJC6Jl66OMhn1fCWE+YBJ8iTkrZJrw3cMxv4QUw/RWHt44y9PZpDiV5Q9P
nhJqkdpCNCwbydrKly8A9TvqmBWY1twxDX1K1TxrvR6+aeTvx5CRKsDFliC2TsEy6pzE7o7d5opH
yM51qmAqiMqbrYASyBxvFxF3wPKnfYmoLmrL9xT0oDQPddIf/OxsEsGwAseGKzqpxLRDjS3qUsLr
BfiMq6rdk+ImBicZJ32YVA2Y7b9ghbzVf9EdvCluCkicPIb0xRhQcAUPAhYyv6v0WyTheAFwP6jE
a0Q6T8Kp6Sc1hsdfSbqRb37aGIPlU5GSofjXu5ibJ6pNRgIF0JfbY0t0L/7nnHJiVUDUdeZxdv4c
hO7KEjWqOdejU/qeRdFo4OSaGts/nfnEJkbtwa6B/gssHeueuskROX9UZvUb9F7ODYd8rmjqFOFB
E+JhRrrOPBtkBCAjK7ZWIq+1ZK8ICd6FvPUZGmBrtBbDWfcO3u7fu/Kr9A2X1Ic58HNUqWCTpxha
Y0SEnLGYKuRMNAxksVIHxFy1B0QU6LhGXl52nfeDYy28n7Zg8fJkf6dD8/aEdRv5hAUuUu6rcKsf
gXJT330Nj13Uo3r8RIvExJNIjuK2SILX+a+GUV1/665KkFAJ2CETaN1Ho3HNLFHbgbeJ3qolQINX
bBv3xv9cT1q7xvFZPeY6mUuDRqgJrdUp8K3uAFxxdjilXwIdKBCwzzkzzdauivcfKxyWZ9hKo/jW
LaR2QNF8nBF1QR6CRdJmz8sImf8kpsYhObJSG9LfWmEuU+UgLs0vnvQtZfMSXMjV75Eug/7rLa90
af++ozYWiR7jvoVx4+0vVF4X5YYgg/GCBzo8EqMvFNFQlALbXWbj0oqsuBqZspD6=
HR+cPvxqDG3gH8utWqgW8thyvPvNkM6DIyo1kFG7pLhIu8gk++GhRmy2oDsR7tPn6GhM/VkB579D
4KHelvmVd7Jvh8DFY2mRJm6+xk9f44yaOPMK0dYonDUkNkuDaY+/69bBk+rBJgBECVLkCW2PYgKa
r48PzyrJS3kb/O2Vl5vDXlGNcSH42TplwTTL418+yuCLg3sD0Ww4FUDGMmSSKTCeeVPl0eE6K3Dr
MRBsp8cJ92gKrthEL4smqKfgSnnDIN87eTwHaeNPiQEEkQQIh025pzkBr7tTlA6BQRpL5AD3J9BI
YMBeG2To9BAGAYWgp+5xVIAPSB882R1IzAw2m5loZeWgClLDHzn3Dc2oSeJ9b8mgkkGNBzgHddzJ
eNCeP2fhdGJJhvp8jSEURmz6J5t2rsOAu4UvhgAiDwKzBu5a3iN31B2mZzD68DP0Fv6JDmEG6ibw
NMwfJcFqsPu7R8oaZ/Y/nYUgbq7Vrf6uczMhYcHOv4Cc1tMElk/rLnkgkymFPhkvZ80OhgAwKaWl
IZWEJG0mO4vS0NfU80SSuT/GacSGuZ6uJNi5NSRl4RBbl/TWujPW2mzp8tbI5Fj5Z3zlxPeAZJu4
PYoRA2bshRMm7VjBNs3glAYOeWJT5sVcZkZFcvKlW+u46PDo+ZzZiHEETt9K/m+dZoz0oIIVcg9/
TniEQkaZfBOpUxh2tS6IlJ/oMalUHFHjk3LMtub9Si35vIvt5i3794SX50Zmulr9eOSJJCHUqv7b
5Z2ZO/SorWhSG1lMX/4sDEVyUnKi73vA8mhaYAJx6Seox9dhfu7cd3GGONOfOg7fdAroO0gK59Tm
jRkosVDV64shLzuxXmPr3+cDOCMuBTd5JYJ11dGmtc7b6q3gVLPC03gShhVCRma=
